--[[
Copyright (C) Achimobil

Author: Achimobil
Date: 28.02.2023
Version: 0.1.0.0

Contact:
https://discord.gg/Va7JNnEkcW

History:
V 0.1.0.0 @ 28.02.2023 - First Version.

Important:
Free for use in other mods - no permission needed, only provide my name.
No changes are to be made to this script without permission from Achimobil.

Frei verwendbar - keine erlaubnis nötig, Namensnennung im Mod erforderlich.
An diesem Skript dürfen ohne Genehmigung von Achimobil keine Änderungen vorgenommen werden.
]]

BuyingStationCategoriesSpecialization = {
	Version = "0.1.0.0",
	Name = "BuyingStationCategoriesSpecialization"
}
print(g_currentModName .. " - init " .. BuyingStationCategoriesSpecialization.Name .. "(Version: " .. BuyingStationCategoriesSpecialization.Version .. ")");

function BuyingStationCategoriesSpecialization.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(PlaceableBuyingStation, specializations);
end

function BuyingStationCategoriesSpecialization.registerEventListeners(placeableType)
	SpecializationUtil.registerEventListener(placeableType, "onLoad", BuyingStationCategoriesSpecialization);
end

function BuyingStationCategoriesSpecialization.registerXMLPaths(schema, basePath)
	schema:register(XMLValueType.STRING, basePath .. ".buyingStation#fillTypeCategories", "Fill type categories")
	schema:register(XMLValueType.STRING, basePath .. ".buyingStation#statsName", "Name in stats", "other")
	schema:register(XMLValueType.FLOAT, basePath .. ".buyingStation#priceScale", "Price scale", 1)
end

function BuyingStationCategoriesSpecialization:onLoad(savegame)
	local buyingStation = self.spec_buyingStation.buyingStation
-- print("self")
-- DebugUtil.printTableRecursively(self,"_",0,2)

	local key = "placeable.buyingStation"
	local fillTypeCategories = self.xmlFile:getValue(key .. "#fillTypeCategories")
	local priceScale = self.xmlFile:getValue(key .. "#priceScale", 1)
	
	local fillTypeStatsName = self.xmlFile:getValue(key .. "#statsName", "other")
	if FinanceStats.statNameToIndex[fillTypeStatsName] == nil then
		Logging.xmlWarning(self.xmlFile, "StatsName '%s' for fillType '%s' is not defined for BuyingStationCategories", fillTypeStatsName, fillTypeStr)

		fillTypeStatsName = "other"
	end
	
	if fillTypeCategories ~= nil then
		local fillTypes = g_fillTypeManager:getFillTypesByCategoryNames(fillTypeCategories, "Warning: BuyingStationCategories has invalid fillTypeCategory '%s'.")

		for _, fillTypeIndex in pairs(fillTypes) do
			if fillTypeIndex ~= nil then
				if buyingStation.supportedFillTypes[fillTypeIndex] ~= nil then
					buyingStation.fillTypePricesScale[fillTypeIndex] = priceScale
					buyingStation.fillTypeStatsName[fillTypeIndex] = fillTypeStatsName
					buyingStation.providedFillTypes[fillTypeIndex] = true
				else
					Logging.xmlWarning(self.xmlFile, "FillType '%s' is not supported by loading triggers for buying station", fillTypeStr)
				end
			end		
		end
	end
end